%define gs_ver 8.70
%define gs_dot_ver 8.70

Summary: A PostScript(TM) interpreter and renderer.
Name: ghostscript
Version: %{gs_ver}

Release: 2

License: AFPL (Aladdin Free Public License)
URL: http://www.ghostscript.com/
Group: Applications/Publishing
Source0: %{name}-%{gs_ver}.tar.bz2

Patch0: %{name}-%{version}-aix.patch
Patch1: %{name}-scripts.patch
Patch2: %{name}-runlibfileifexists.patch
Patch3: %{name}-system-jasper.patch
Patch4: %{name}-pksmraw.patch
Patch5: %{name}-jbig2dec-nullderef.patch
Patch6: %{name}-gs-executable.patch
Patch7: %{name}-cups-filters.patch

BuildRoot: %{_tmppath}/%{name}-%{gs_ver}-%{release}-root

BuildRequires: make, patch

BuildRequires: cairo-devel >= 1.10.0
BuildRequires: cups-devel >= 1.4.4-2
BuildRequires: fontconfig-devel >= 2.8.0
BuildRequires: jasper-devel >= 1.900.1
BuildRequires: libiconv >= 1.14-2
BuildRequires: libjpeg-devel >= 6b
BuildRequires: libpaper-devel >= 1.1.23-3
BuildRequires: libpng-devel >= 1.2.46
BuildRequires: zlib-devel >= 1.2.3

Requires: cairo >= 1.10.0
Requires: cups-libs >= 1.4.4-2
Requires: fontconfig >= 2.8.0
Requires: jasper >= 1.900.1
Requires: libiconv >= 1.14-2
Requires: libjpeg >= 6b
Requires: libpaper >= 1.1.23-3
Requires: libpng >= 1.2.46
Requires: zlib >= 1.2.3

Requires: urw-fonts >= 2.4
Requires: ghostscript-fonts >= 8.11


%description
Ghostscript is a set of software that provides a PostScript(TM)
interpreter, a set of C procedures (the Ghostscript library, which
implements the graphics capabilities in the PostScript language) and
an interpreter for Portable Document Format (PDF) files. Ghostscript
translates PostScript code into many common, bitmapped formats, like
those understood by your printer or screen. Ghostscript is normally
used to display PostScript files and to print PostScript files to
non-PostScript printers.

If you need to display PostScript files or print them to
non-PostScript printers, you should install ghostscript. If you
install ghostscript, you also need to install the ghostscript-fonts
package.


%package devel
Summary: Files for developing applications that use %{name}.
Requires: %{name} = %{version}-%{release}
Group: Development/Libraries

%description devel
The header files for developing applications that use %{name}.


%package doc
Summary: Documentation for %{name}.
Requires: %{name} = %{version}-%{release}
Group: Documentation

%description doc
The documentation files that come with %{name}.


%package cups
Summary: CUPS filter and conversion rules for interpreting PostScript and PDF.
Requires: %{name} = %{version}-%{release}
Requires: cups >= 1.4.4-2
Group: System Environment/Daemons

%description cups
CUPS filter and conversion rules for interpreting PostScript and PDF.


%prep
%setup -q
rm -rf jasper jpeg libpng

export PATH=/opt/freeware/bin:$PATH

# necessary fix to successfully compile with XLC/C++ V7 on AIX
%patch0

# fix some shell scripts
%patch1 -p1 -b .scripts

# define .runlibfileifexists.
%patch2 -p1

# use the system jasper library
%patch3 -p1 -b .system-jasper

# fix pksmraw output (bug #308211).  Still needed in 8.63.
%patch4 -p1 -b .pksmraw

# applied patch to fix NULL dereference in JBIG2 decoder (bug #501710).
%patch5 -p1 -b .jbig2dec-nullderef

# fix scripts so they don't get broken on install (bug #502550).
%patch6 -p1 -b .gs-executable

# Install CUPS filter convs files in the correct place.
%patch7 -p1 -b .cups-filters

%build
export CC="gcc -D_LARGE_FILES"
export CFLAGS="-DSYSV -D_AIX -D_AIX32 -D_AIX41 -D_AIX43 -D_AIX51 -D_ALL_SOURCE -DFUNCPROTO=15 -O -I/opt/freeware/include"
export LDFLAGS="-L/opt/freeware/lib -Wl,-blibpath:/opt/freeware/lib:/usr/lib:/lib -Wl,-bmaxdata:0x80000000"

export FT_CFLAGS=$(pkg-config --cflags freetype2)

./configure \
    --prefix=%{_prefix} \
    --enable-fontconfig \
    --enable-cups \
    --enable-gtk \
    --enable-cairo \
    --with-libpaper \
    --with-pdftoraster \
    --with-ijs \
    --with-jbig2dec \
    --with-jasper \
    --with-omni \
    --with-x \
    --with-drivers=ALL

gmake %{?_smp_mflags}

# build IJS
cd ijs
./autogen.sh
./configure \
    --prefix=%{_prefix} \
    --enable-shared --disable-static
gmake %{?_smp_mflags}
cd ..

gmake cups


%install
[ "${RPM_BUILD_ROOT}" != "/" ] && rm -rf ${RPM_BUILD_ROOT}

gmake prefix=${RPM_BUILD_ROOT}%{_prefix} install \
    CUPSSERVERROOT=${RPM_BUILD_ROOT}`cups-config --serverroot` \
    CUPSSERVERBIN=${RPM_BUILD_ROOT}`cups-config --serverbin` \
    CUPSDATA=${RPM_BUILD_ROOT}`cups-config --datadir`

cd ijs
gmake prefix=${RPM_BUILD_ROOT}%{_prefix} install
cd ..

/usr/bin/strip ${RPM_BUILD_ROOT}%{_bindir}/* || :
/usr/bin/strip ${RPM_BUILD_ROOT}%{_libdir}/cups/filter/* || :

# install header files
mkdir -p ${RPM_BUILD_ROOT}%{_includedir}/%{name}
cp base/errors.h ${RPM_BUILD_ROOT}%{_includedir}/%{name}
cp base/gdevdsp.h ${RPM_BUILD_ROOT}%{_includedir}/%{name}
cp psi/iapi.h ${RPM_BUILD_ROOT}%{_includedir}/%{name}
cp psi/ierrors.h ${RPM_BUILD_ROOT}%{_includedir}/%{name}
chmod 644 ${RPM_BUILD_ROOT}%{_includedir}/%{name}/*

mkdir -p ${RPM_BUILD_ROOT}%{_docdir}/%{name}-%{gs_dot_ver}
mv ${RPM_BUILD_ROOT}%{_datadir}/%{name}/%{gs_dot_ver}/doc/* ${RPM_BUILD_ROOT}%{_docdir}/%{name}-%{gs_dot_ver}
rmdir ${RPM_BUILD_ROOT}%{_datadir}/%{name}/%{gs_dot_ver}/doc/

mkdir -p ${RPM_BUILD_ROOT}%{_mandir}
mv ${RPM_BUILD_ROOT}%{_datadir}/man/* ${RPM_BUILD_ROOT}%{_mandir}
rm -rf ${RPM_BUILD_ROOT}%{_datadir}/man

(
  cd ${RPM_BUILD_ROOT}
  for dir in bin include lib
  do
    mkdir -p usr/${dir}
    cd usr/${dir}
    ln -sf ../..%{_prefix}/${dir}/* .
    cd -
  done
)


%clean
[ "${RPM_BUILD_ROOT}" != "/" ] && rm -rf ${RPM_BUILD_ROOT}


%files
%defattr(-,root,system)
%{_bindir}/*
%{_libdir}/*.a
%{_mandir}/man?/*
%{_mandir}/??/man?/*
%{_datadir}/%{name}/%{gs_dot_ver}
/usr/bin/*
/usr/lib/*.a


%files devel
%defattr(-,root,system)
%{_includedir}/*
%{_libdir}/*.la
/usr/include/*
/usr/lib/*.la


%files doc
%defattr(-,root,system)
%doc %{_docdir}/%{name}-%{gs_dot_ver}


%files cups
%defattr(-,root,system)
%{_libdir}/cups/filter/*
%{_datadir}/cups/model/pxl*
%{_datadir}/cups/mime/*.convs


%changelog
* Sun Jan 06 2013 Michael Perzl <michael@perzl.org> - 8.70-2
- added a 'devel' and 'cups' package
- enabled cairo and thus added a dependency on cairo
- added a dependency on libiconv

* Tue Sep 15 2009 Michael Perzl <michael@perzl.org> - 8.70-1
- updated to version 8.70

* Tue Sep 15 2009 Michael Perzl <michael@perzl.org> - 8.64-1
- updated to version 8.64

* Tue Sep 15 2009 Michael Perzl <michael@perzl.org> - 8.62-3
- fixed some minor spec file issues

* Wed Apr 23 2008 Michael Perzl <michael@perzl.org> - 8.62-2
- some minor spec file fixes

* Wed Mar 05 2008 Michael Perzl <michael@perzl.org> - 8.62-1
- updated to version 8.62

* Thu Feb 21 2008 Michael Perzl <michael@perzl.org> - 8.61-1
- updated to version 8.61

* Fri Sep 28 2007 Michael Perzl <michael@perzl.org> - 8.60-1
- first version for AIX V5.1 and higher
